function [y,yq,xq,eq]=mu_law_compress_expand(x,nbits,mu,Xmax);
%
% function to mu-law compress input signal
%
% Inputs:
%   x: input signal in range -1 to +1
%   nbits: number of bits/sample for uniform quantizer
%   mu: size 0f mu-law compression
%   Xmax: maximum value of input signal (+1)
%
% Output:
%   y: mu-law compressed signal
%   yq: mu-law compressed and quantized signal
%   xq: mu-law compressed, quantized, and expanded signal
%   eq: quantization error signal

% mu law compress x[n]
    y=Xmax*(log(1+mu*abs(x)/Xmax)/log(1+mu)).*sign(x);
    
% uniform quantization using nbits quantizer
    yq=fxquant(y,nbits,'round','sat');
    
% mu law expand yq[n]
    xq=(exp(abs(yq)*log(1+mu)/Xmax)-1)*Xmax/mu;
    xq=xq.*sign(yq);
    
% compute error signal
    eq=xq-x;
end